===============================
ntv
===============================

.. image:: https://badge.fury.io/py/ntv.png
    :target: http://badge.fury.io/py/ntv
    
.. image:: https://travis-ci.org/onjin/ntv.png?branch=master
        :target: https://travis-ci.org/onjin/ntv

.. image:: https://pypip.in/d/ntv/badge.png
        :target: https://crate.io/packages/ntv?version=latest


n.tv api

* Free software: BSD license

Features
--------

* python wrapper over tv program from n.pl site
* ntv-cli command utility to list and search tv program
